@@ -64,7 +64,7 @@ log = logging.getLogger(__name__)
 
 
 class Client(object):
-    __version__ = '0.5.5'
+    __version__ = '0.5.6'
     __protocol_version__ = '0.3.5'
 
     def __init__(self, config=None, register_timing=True):
@@ -294,7 +294,9 @@ class Client(object):
         return structure
 
     def py_report(self, environ, traceback=None, message=None, http_status=200,
-                  start_time=None, request_stats={}):
+                  start_time=None, request_stats=None):
+        if not request_stats:
+            request_stats = {}
         report_data, errormator_info = self.create_report_structure(environ,
                         traceback, server=self.config['server_name'],
                         http_status=http_status, include_params=True)
@@ -354,7 +356,9 @@ class Client(object):
         return True
 
     def py_slow_report(self, environ, start_time, end_time, records=(),
-                       request_stats={}):
+                       request_stats=None):
+        if not request_stats:
+            request_stats = {}
         report_data, errormator_info = self.create_report_structure(environ,
                     server=self.config['server_name'], include_params=True)
         report_data = self.filter_callable(report_data, 'slow_report')
@@ -434,7 +438,13 @@ class Client(object):
         else:
             remote_addr = (environ.get("HTTP_X_REAL_IP")
                            or environ.get('REMOTE_ADDR'))
+        parsed_environ['HTTP_USER_AGENT'] = environ.get("HTTP_USER_AGENT", '')
         parsed_environ['REMOTE_ADDR'] = remote_addr
+        try:
+            errormator_info['username'] = u'%s' % environ.get('REMOTE_USER',
+                                    errormator_info.get('username', u''))
+        except (UnicodeEncodeError, UnicodeDecodeError) as e:
+            errormator_info['username'] = "undecodable"
         try:
             errormator_info['URL'] = req.url
         except (UnicodeEncodeError, UnicodeDecodeError) as e:
@@ -464,10 +474,8 @@ class Client(object):
         detail_entry['request'] = parsed_environ
         # fill in all other required info
         detail_entry['ip'] = parsed_environ.get('REMOTE_ADDR', u'')
-        detail_entry['user_agent'] = parsed_environ.get('HTTP_USER_AGENT', u'')
-        detail_entry['username'] = parsed_environ.get('REMOTE_USER',
-                                                parsed_environ.get('username',
-                                                                   ''))
+        detail_entry['user_agent'] = parsed_environ['HTTP_USER_AGENT']
+        detail_entry['username'] = errormator_info.pop('username')
         detail_entry['url'] = errormator_info.pop('URL', 'unknown')
         if 'request_id' in errormator_info:
             detail_entry['request_id'] = errormator_info.pop('request_id',
@@ -504,7 +512,9 @@ def get_config(config=None, path_to_config=None, section_name='errormator'):
 
 
 def decorate(ini_file=None, register_timing=True):
-    def make_errormator_middleware(app, global_config={}, **kw):
+    def make_errormator_middleware(app, global_config=None, **kw):
+        if not global_config:
+            global_config = {}
         config = global_config.copy()
         config.update(kw)
         # this shuts down all errormator functionalities
@@ -526,7 +536,7 @@ def decorate(ini_file=None, register_timing=True):
 
 
 # TODO: refactor this to share the code
-def make_errormator_middleware(app, global_config={}, **kw):
+def make_errormator_middleware(app, global_config=None, **kw):
     if global_config:
         config = global_config.copy()
     else:
