@@ -48,7 +48,7 @@ import os
 import inspect
 import traceback
 import codecs
-
+from errormator_client.client import PY3
 
 _coding_re = re.compile(r'coding[:=]\s*([-\w.]+)')
 _line_re = re.compile(r'^(.*?)$(?m)')
@@ -224,7 +224,10 @@ class Traceback(object):
     def exception(self):
         """String representation of the exception."""
         buf = traceback.format_exception_only(self.exc_type, self.exc_value)
-        return ''.join(buf).strip().decode('utf-8', 'replace')
+        if PY3:
+            return ''.join(buf).strip()
+        else:
+            return ''.join(buf).strip().decode('utf-8', 'replace')
 
     def log(self, logfile=None):
         """Log the ASCII traceback into a file object."""
@@ -276,16 +279,6 @@ class Frame(object):
                 info = str(info).decode('utf-8', 'replace')
         self.info = info
 
-    def eval(self, code, mode='single'):
-        """Evaluate code in the context of the frame."""
-        if isinstance(code, basestring):
-            if isinstance(code, unicode):
-                code = UTF8_COOKIE + code.encode('utf-8')
-            code = compile(code, '<interactive>', mode)
-        if mode != 'exec':
-            return eval(code, self.globals, self.locals)
-        exec code in self.globals, self.locals
-
     @cached_property
     def sourcelines(self):
         """The sourcecode of the file as list of unicode strings."""
