@@ -1,6 +1,7 @@
 from errormator_client.utils import import_module, deco_func_or_method
 from errormator_client.timing import time_trace
 
+ignore_set = frozenset(['remote', 'nosql'])
 
 def add_timing(min_duration=3):
     module = import_module('urllib3')
@@ -10,7 +11,8 @@ def add_timing(min_duration=3):
     def gather_args_url(r, m, url, *args, **kwargs):
         return {'type':'remote',
                 'statement':'urllib3.request.RequestMethods.request_encode_url',
-                'parameters':url}
+                'parameters':url,
+                'ignore_in': ignore_set}
 
     deco_func_or_method(module.request, 'RequestMethods.request_encode_url',
                         time_trace, gather_args_url, min_duration)
@@ -19,7 +21,8 @@ def add_timing(min_duration=3):
     def gather_args_body(r, m, url, *args, **kwargs):
         return {'type':'remote',
                 'statement':'urllib3.request.RequestMethods.request_encode_body',
-                'parameters':url}
+                'parameters':url,
+                'ignore_in': ignore_set}
 
     deco_func_or_method(module.request, 'RequestMethods.request_encode_body',
                         time_trace, gather_args_body, min_duration)
